;----------========== Parsing (common to every scripts) ==========----------
; The script is being passed 2 parameters by mGalaxy.
; The first one contains the full path to the emulator.
; The second one contains parameters (optional) for the emulator PLUS the full path (between quotes) to the rom file.
;
; Line 13: $CmdLine is an array of size 3. $CmdLine[0] returns the total number of items in the array, $CmdLine[1] the 1st parameter, $CmdLine[2] the 2nd parameter
; Line 19: AutoIt requires that parameters sent by mGalaxy be enclosed in quotation marks.
;          As the parameters themselves contain quotation marks, these have been replaced by a distinguishing sign (%s) so as not to cause any confusion in the constitution of the command line.
;          So we now replace this distinguishing sign with quotation marks.
; Line 20: Some apps (MESS for instance, when it searchs for a system Bios) need to know the path to their 'Working Directory'. We do extract it from the emulator full path.
;
#include <MsgBoxConstants.au3>
If UBound($CmdLine) <> 3 Then
   MsgBox($MB_SYSTEMMODAL, "Script execution error", "The script was expecting to receive 2 parameters but received " & UBound($CmdLine)-1, 10)
   Exit 0
EndIf

local $app = $CmdLine[1]
local $command = StringReplace($CmdLine[2], "%s", """")
Local $workingDir = StringRegExpReplace($app, "\\[^\\]*$", "")
FileChangeDir($workingDir)
;---------------------------------------------------------------------------

HotKeySet("{ESC}", "Terminate")

; override the default cmd.exe parameters formating by removing the starting '"/C ' and ending '"'
$command = StringTrimLeft($command, 4 )
$command = StringTrimRight($command, 1 )

; resolve .lnk path (https://www.autoitscript.com/autoit3/docs/functions/FileGetShortcut.htm)
Local $aDetails = FileGetShortcut($command)
If @error Then
	Exit 0
EndIf

; override the previously set Working Directory
FileChangeDir($aDetails[1])

; launch app
$PID = Run ($aDetails[0] & " " & $aDetails[2])
;Allow window to initialize...
Sleep (500)
;Get HWND.
$hWnd = _GetHwndFromPID($PID)
;Make it foreground
WinActivate($hWnd)
WinSetState($hWnd, "", @SW_MAXIMIZE)
;WinSetOnTop($hWnd, "", 1)

While ProcessExists ( $PID )
   sleep(500)
WEnd

Exit 0

;Terminate function
Func Terminate()
   While ProcessExists ( $PID )
	  ProcessClose ( $PID )
   WEnd
   Exit 0
EndFunc

;HWND from PID function
Func _GetHwndFromPID($PID)
	$hWnd = 0
	$winlist = WinList()
	Do
		For $i = 1 To $winlist[0][0]
			If $winlist[$i][0] <> "" Then
				$iPID2 = WinGetProcess($winlist[$i][1])
				If $iPID2 = $PID Then
					$hWnd = $winlist[$i][1]
					ExitLoop
				EndIf
			EndIf
		Next
	Until $hWnd <> 0
	Return $hWnd
EndFunc